==> asymptote-0.83.tar.gz: asymptote-0.83/camp.tab.h <==
/* A Bison parser, made by GNU Bison 2.0a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ID = 258,
     OP = 259,
     ADD = 260,
     SUBTRACT = 261,
     TIMES = 262,
     DIVIDE = 263,
     MOD = 264,
     EXPONENT = 265,
     DOTS = 266,
     COLONS = 267,
     DASHES = 268,
     LONGDASH = 269,
     INCR = 270,
     CONTROLS = 271,
     TENSION = 272,
     ATLEAST = 273,
     CURL = 274,
     CYCLE = 275,
     COR = 276,
     CAND = 277,
     EQ = 278,
     NEQ = 279,
     LT = 280,
     LE = 281,
     GT = 282,
     GE = 283,
     CARETS = 284,
     LOGNOT = 285,
     STRING = 286,
     LOOSE = 287,
     ASSIGN = 288,
     DIRTAG = 289,
     JOIN_PREC = 290,
     AND = 291,
     ELLIPSIS = 292,
     IMPORT = 293,
     STRUCT = 294,
     TYPEDEF = 295,
     NEW = 296,
     IF = 297,
     ELSE = 298,
     WHILE = 299,
     DO = 300,
     FOR = 301,
     BREAK = 302,
     CONTINUE = 303,
     RETURN_ = 304,
     STATIC = 305,
     PUBLIC_TOK = 306,
     PRIVATE_TOK = 307,
     THIS = 308,
     EXPLICIT = 309,
     LIT = 310,
     UNARY = 311
   };
#endif
#define ID 258
#define OP 259
#define ADD 260
#define SUBTRACT 261
#define TIMES 262
#define DIVIDE 263
#define MOD 264
#define EXPONENT 265
#define DOTS 266
#define COLONS 267
#define DASHES 268
#define LONGDASH 269
#define INCR 270
#define CONTROLS 271
#define TENSION 272
#define ATLEAST 273
#define CURL 274
#define CYCLE 275
#define COR 276
#define CAND 277
#define EQ 278
#define NEQ 279
#define LT 280
#define LE 281
#define GT 282
#define GE 283
#define CARETS 284
#define LOGNOT 285
#define STRING 286
#define LOOSE 287
#define ASSIGN 288
#define DIRTAG 289
#define JOIN_PREC 290
#define AND 291
#define ELLIPSIS 292
#define IMPORT 293
#define STRUCT 294
#define TYPEDEF 295
#define NEW 296
#define IF 297
#define ELSE 298
#define WHILE 299
#define DO 300
#define FOR 301
#define BREAK 302
#define CONTINUE 303
#define RETURN_ 304
#define STATIC 305
#define PUBLIC_TOK 306
#define PRIVATE_TOK 307
#define THIS 308
#define EXPLICIT 309
#define LIT 310
#define UNARY 311




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 38 "camp.y"
typedef union YYSTYPE {
  position pos;
  //sym::symbol *sym;
  struct {
    position pos;
    sym::symbol *sym;
  } ps;
  absyntax::name *n;
  absyntax::varinit *vi;
  absyntax::arrayinit *ai;
  absyntax::exp *e;
  absyntax::specExp *se;
  absyntax::joinExp *j;
  absyntax::explist *elist;
  absyntax::argument arg;
  absyntax::arglist *alist;
  absyntax::dimensions *dim;
  absyntax::ty  *t;
  absyntax::decid *di;
  absyntax::decidlist *dil;
  absyntax::decidstart *dis;
  absyntax::runnable *run;
  absyntax::modifierList *ml;
  struct {
    position pos;
    int keyword;
  } mod;
  //absyntax::program *prog;
  absyntax::vardec *vd;
  //absyntax::vardecs *vds;
  absyntax::dec *d;
  absyntax::stm *s;
  absyntax::blockStm *bs;
  absyntax::stmExpList *sel;
  //absyntax::funheader *fh;
  absyntax::formal *fl;
  absyntax::formals *fls;
  absyntax::file *fil;
} YYSTYPE;
/* Line 1380 of yacc.c.  */
#line 189 "camp.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> asymptote-0.87.tar.gz: asymptote-0.87/camp.tab.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     ID = 258,
     OP = 259,
     ADD = 260,
     SUBTRACT = 261,
     TIMES = 262,
     DIVIDE = 263,
     MOD = 264,
     EXPONENT = 265,
     DOTS = 266,
     COLONS = 267,
     DASHES = 268,
     LONGDASH = 269,
     INCR = 270,
     CONTROLS = 271,
     TENSION = 272,
     ATLEAST = 273,
     CURL = 274,
     CYCLE = 275,
     COR = 276,
     CAND = 277,
     EQ = 278,
     NEQ = 279,
     LT = 280,
     LE = 281,
     GT = 282,
     GE = 283,
     CARETS = 284,
     LOGNOT = 285,
     STRING = 286,
     LOOSE = 287,
     ASSIGN = 288,
     DIRTAG = 289,
     JOIN_PREC = 290,
     AND = 291,
     ELLIPSIS = 292,
     IMPORT = 293,
     STRUCT = 294,
     TYPEDEF = 295,
     NEW = 296,
     IF = 297,
     ELSE = 298,
     WHILE = 299,
     DO = 300,
     FOR = 301,
     BREAK = 302,
     CONTINUE = 303,
     RETURN_ = 304,
     STATIC = 305,
     PUBLIC_TOK = 306,
     PRIVATE_TOK = 307,
     THIS = 308,
     EXPLICIT = 309,
     LIT = 310,
     PERM = 311,
     MODIFIER = 312,
     UNARY = 313
   };
#endif
#define ID 258
#define OP 259
#define ADD 260
#define SUBTRACT 261
#define TIMES 262
#define DIVIDE 263
#define MOD 264
#define EXPONENT 265
#define DOTS 266
#define COLONS 267
#define DASHES 268
#define LONGDASH 269
#define INCR 270
#define CONTROLS 271
#define TENSION 272
#define ATLEAST 273
#define CURL 274
#define CYCLE 275
#define COR 276
#define CAND 277
#define EQ 278
#define NEQ 279
#define LT 280
#define LE 281
#define GT 282
#define GE 283
#define CARETS 284
#define LOGNOT 285
#define STRING 286
#define LOOSE 287
#define ASSIGN 288
#define DIRTAG 289
#define JOIN_PREC 290
#define AND 291
#define ELLIPSIS 292
#define IMPORT 293
#define STRUCT 294
#define TYPEDEF 295
#define NEW 296
#define IF 297
#define ELSE 298
#define WHILE 299
#define DO 300
#define FOR 301
#define BREAK 302
#define CONTINUE 303
#define RETURN_ 304
#define STATIC 305
#define PUBLIC_TOK 306
#define PRIVATE_TOK 307
#define THIS 308
#define EXPLICIT 309
#define LIT 310
#define PERM 311
#define MODIFIER 312
#define UNARY 313




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 41 "camp.y"
typedef union YYSTYPE {
  position pos;
  //sym::symbol *sym;
  struct {
    position pos;
    sym::symbol *sym;
  } ps;
  absyntax::name *n;
  absyntax::varinit *vi;
  absyntax::arrayinit *ai;
  absyntax::exp *e;
  absyntax::specExp *se;
  absyntax::joinExp *j;
  absyntax::explist *elist;
  absyntax::argument arg;
  absyntax::arglist *alist;
  absyntax::dimensions *dim;
  absyntax::ty  *t;
  absyntax::decid *di;
  absyntax::decidlist *dil;
  absyntax::decidstart *dis;
  absyntax::runnable *run;
  struct {
    position pos;
    trans::permission val;
  } perm;
  struct {
    position pos;
    trans::modifier val;
  } mod;
  absyntax::modifierList *ml;
  //absyntax::program *prog;
  absyntax::vardec *vd;
  //absyntax::vardecs *vds;
  absyntax::dec *d;
  absyntax::stm *s;
  absyntax::blockStm *bs;
  absyntax::stmExpList *sel;
  //absyntax::funheader *fh;
  absyntax::formal *fl;
  absyntax::formals *fls;
  absyntax::file *fil;
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 197 "camp.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
